import React, { useEffect, useState } from "react";
import { Spin, Image, ImageViewer } from "antd";
import { uploadImage } from "../../utils/upload";
// import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
// import { faAdd, faClose } from "@fortawesome/free-solid-svg-icons";
import { FileAddFilled, CloseCircleFilled } from "@ant-design/icons";
export default function UploadImgs({ assets, getImgs, multiple }) {
  const maxCount = 6;
  const [fileList, setFileList] = useState([]);
  const [loading, setLoading] = useState(false);
  // useEffect(() => {
  //   if (!assets) {
  //     setFileList([]);
  //   }
  // }, assets);
  const handleUploadImage = async (e) => {
    let file = e.target.files[0];
    if (!file) return;
    setLoading(true);
    if (file.type.indexOf("image/") != -1) {
      // const image = await uploadImage(file);
      // getImgs((old) => [...old, image.id]);
      const newFiles = [file];
      const newAssets = newFiles.map((item) => ({
        type: "img",
        src: URL.createObjectURL(item),
      }));
      const uploadPromise = uploadImage(file);
      const uploadResult = await Promise.race([
        uploadPromise,
        new Promise((_, reject) =>
          setTimeout(() => reject(new Error("Upload timeout")), 30000)
        ),
      ]);
      console.log("uploadResult", uploadResult);
      setFileList(newAssets);
      getImgs(uploadResult);
    } else if (file.type.indexOf("video/") != -1) {
      if (typeof window == "undefined") return;
      const videoD = document.getElementById("videoD");
      const videoC = document.getElementById("videoC");
      // console.log("videoC", videoC);
      const ctx = videoC?.getContext("2d");
      // 设置Canvas的宽度和高度与视频一致
      videoC.width = videoD.videoWidth;
      videoC.height = videoD.videoHeight;
      // 在Canvas上绘制当前视频帧
      ctx.drawImage(videoD, 0, 0, videoC.width, videoC.height);
      // 将Canvas转换为图片URL
      const frameImageUrl = videoC.toDataURL();

      // 输出图片URL
      // console.log(frameImageUrl);
      // console.log("ddddd", file, {
      //   type: "video",
      //   src: frameImageUrl,
      // });
      // const video = await uploadVideo(file);
      // getImgs((old) => [...old, video.id]);
      // setFileList((old) => [...old, video]);
      const newFiles = [...assets, file];
      const newAssets = newFiles.map((item) => ({
        type: "video",
        src: URL.createObjectURL(item),
      }));
      setFileList(newAssets);
    }

    setLoading(false);
  };
  const handleRemoveItem = (index) => {
    // console.log(index);
    let newArr = [...fileList];
    newArr.splice(index, 1);
    setFileList(newArr);
    getImgs(newArr);
  };
  return (
    <div>
      <div className="grid grid-cols-4 gap-1 h-28">
        {fileList.map((item, index) => {
          return (
            <div key={index} className="rounded relative">
              <Image
                src={item?.src}
                width="100%"
                height="100%"
                className="rounded"
              />
              <div
                className="h-4 w-4 bg-[#33333380] absolute top-0 right-0 flex justify-center items-center"
                onClick={() => handleRemoveItem(index)}
              >
                <CloseCircleFilled />
              </div>
            </div>
          );
        })}
        {loading && (
          <div className="rounded border-[#00000040] text-[#00000040] flex flex-col justify-center items-center">
            <Spin />
            <p>上传中</p>
          </div>
        )}
        {(multiple || (!multiple && !fileList.length)) && !loading && (
          <label htmlFor="uploadAvatarBtn">
            <div
              className="border-2 border-[#00000040] text-[#00000040] rounded border-dashed w-full h-full flex justify-center items-center"
              // style={{ minHeight: "calc(25vw - 0.75rem)" }}
            >
              <FileAddFilled />
            </div>
          </label>
        )}
        <input
          type="file"
          id="uploadAvatarBtn"
          multiple={multiple}
          style={{ display: "none" }}
          // accept="image/png, image/jpeg, video/*"
          accept="image/png, image/jpeg, image/jpg"
          // capture="camera"
          onChange={handleUploadImage}
        />
      </div>
      <div className="hidden">
        <video id="videoD">
          <source src={fileList[0]?.src} />
          您的浏览器不支持 Video 标签。
        </video>
        <canvas id="videoC" />
      </div>
    </div>
  );
}
// export async function mockUpload(file) {
//   await sleep(3000)
//   return {
//     url: URL.createObjectURL(file),
//   }
// }
