import React, { useState, useRef, useEffect } from "react";
import { Form, Input, Button, Space, Table, Menu, Image } from "antd";
import {
  Routes,
  Route,
  Navigate,
  useNavigate,
  useLocation,
} from "react-router-dom";
import baseRequest from "../../utils/baseRequest";
import VideoPlayer from "../../components/VideoPlayer";
const PostMachineReviewContent = (props) => {
  const { TextArea } = Input;
  const current = props.current;
  //表头
  const columns = [
    {
      title: "发帖人",
      dataIndex: "creator",
      key: "creator",
      render: (data) => (
        <div>
          <Image src={data?.avatar?.images[0]?.urls[0]} width={50} />
          <p>
            ID：<span className="text-red-400">{data?.user_id}</span>
          </p>
          <p>
            昵称：<span className="text-red-400">{data?.name}</span>
          </p>
        </div>
      ),
    },
    {
      title: "动态内容",
      dataIndex: "newMedia",
      key: "newMedia",
      width: 500,
      render: (data) => (
        <div className="flex flex-col">
          <div>
            <p className="text-red-400">
              文案：<span className="text-black">{data.text}</span>
            </p>
          </div>
          <p className="text-red-400">媒体：</p>
          <div
            className={`grid ${
              (data.media?.images[0]?.h <= data.media?.images[0]?.w &&
                data.media?.images.length < 4) ||
              data.media?.images.length === 0
                ? "grid-cols-2"
                : "grid-cols-4"
            } gap-2`}
          >
            {data.media?.images?.map((item, index) => (
              <div className="self-start" key={index}>
                <Image src={item.urls[0]} />
              </div>
            ))}
            {data.media?.videos?.map((item, index) => (
              <div className="self-start" key={index}>
                <VideoPlayer url={item.urls[0]} />
              </div>
            ))}
          </div>
        </div>
      ),
    },
    {
      title: "审核结果",
      dataIndex: "info",
      key: "info",
      render: (data) => (
        <div className="flex flex-col">
          <p>文案审核结果：</p>
          <div>
            {data.text?.status === 2 || data.text?.status === 5 ? (
              <p className="text-green-400">无违规</p>
            ) : (
              <div className="flex flex-wrap gap-1">
                {data.text?.spam_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>垃圾审核：</p>
                    <ul>
                      {data.text?.spam_label_details?.map((item, index) => (
                        <li key={index}>{item}</li>
                      ))}
                    </ul>
                  </div>
                )}
                {data.text?.politics_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>敏感审核：</p>
                    <ul>
                      {data.text?.politics_label_details?.map((item, index) => (
                        <li key={index}>{item}</li>
                      ))}
                    </ul>
                  </div>
                )}
                {data.text?.abuse_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>辱骂审核：</p>
                    <ul>
                      {data.text?.abuse_label_details?.map((item, index) => (
                        <li key={index}>{item}</li>
                      ))}
                    </ul>
                  </div>
                )}
                {data.text?.terrorism_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>暴恐审核：</p>
                    <ul>
                      {data.text?.terrorism_label_details?.map(
                        (item, index) => (
                          <li key={index}>{item}</li>
                        )
                      )}
                    </ul>
                  </div>
                )}
                {data.text?.porn_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>鉴黄审核：</p>
                    <ul>
                      {data?.porn_label_details?.map((item, index) => (
                        <li key={index}>{item}</li>
                      ))}
                    </ul>
                  </div>
                )}
                {data.text?.flood_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>灌水审核：</p>
                    <ul>
                      {data.text?.flood_label_details?.map((item, index) => (
                        <li key={index}>{item}</li>
                      ))}
                    </ul>
                  </div>
                )}
                {data.text?.contraband_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>违禁审核：</p>
                    <ul>
                      {data.text?.contraband_label_details?.map(
                        (item, index) => (
                          <li key={index}>{item}</li>
                        )
                      )}
                    </ul>
                  </div>
                )}
              </div>
            )}
          </div>
          <hr className="w-full" />
          <p>媒体审核结果：</p>
          {data.mediaType === "video" && (
            <p
              className={data.media === "" ? "text-green-400" : "text-red-400"}
            >
              {data.media === "" ? "机审通过" : data.media}
            </p>
          )}
          {data.mediaType === "image" && (
            <div>
              {data.media?.map((item, index) => {
                if (item?.status === 2 || item?.status === 5) {
                  return (
                    <p key={index} className="text-green-400">
                      图{index + 1}无违规
                    </p>
                  );
                }
                if (item?.status === 10) {
                  return (
                    <p key={index} className="text-green-400">
                      图{index + 1}审核失败
                    </p>
                  );
                }
                if (!item?.status) {
                  return (
                    <p key={index} className="text-green-400">
                      正在审核中...
                    </p>
                  );
                }

                return (
                  <div key={index}>
                    <p className="text-red-400">图{index + 1}违规情况：</p>
                    <div className="flex flex-wrap gap-1">
                      {item.porn_scene_suggestion &&
                        item.porn_scene_suggestion !== "pass" && (
                          <div className="border-2 border-black bg-gray-200">
                            <p>色情审核：</p>
                            <ul>
                              <li>建议：{item.porn_scene_suggestion}</li>
                              <li>结果：{item.porn_scene_label}</li>
                              <li>结果：{item.porn_scene_rate.toFixed(1)}</li>
                            </ul>
                          </div>
                        )}
                      {item.terrorism_scene_suggestion &&
                        item.terrorism_scene_suggestion !== "pass" && (
                          <div className="border-2 border-black bg-gray-200">
                            <p>暴恐审核：</p>
                            <ul>
                              <li>建议：{item.terrorism_scene_suggestion}</li>
                              <li>结果：{item.terrorism_scene_label}</li>
                              <li>
                                结果：{item.terrorism_scene_rate.toFixed(1)}
                              </li>
                            </ul>
                          </div>
                        )}
                      {item.live_scene_suggestion &&
                        item.live_scene_suggestion !== "pass" && (
                          <div className="border-2 border-black bg-gray-200">
                            <p>不良审核：</p>
                            <ul>
                              <li>建议：{item.live_scene_suggestion}</li>
                              <li>结果：{item.live_scene_label}</li>
                              <li>结果：{item.live_scene_rate.toFixed(1)}</li>
                            </ul>
                          </div>
                        )}
                    </div>
                  </div>
                );
              })}
            </div>
          )}
        </div>
      ),
    },
    {
      title: "提交时间",
      dataIndex: "submitTime",
      key: "submitTime",
    },
    {
      title: "备注",
      dataIndex: "remarks",
      key: "remarks",
      render: (_, record) => (
        <div className="flex flex-col">
          <Form.Item
            name={record.momentId}
            initialValue={record.remarks.manually_review_opinion}
          >
            <TextArea rows={4} disabled={current != "operatorReviewing"} />
          </Form.Item>
        </div>
      ),
    },
    {
      title: "操作",
      dataIndex: "opeartion",
      key: "opeartion",
      render: (_, record) => (
        <div>
          <Space>
            {current === "operatorReviewing" && (
              <Space.Compact direction="vertical">
                <Button type="primary" onClick={() => onClickPass(record)}>
                  通过
                </Button>
                <Button onClick={() => onClickReject(record)}>拒绝</Button>
              </Space.Compact>
            )}
          </Space>
        </div>
      ),
    },
  ];
  //给表单绑定ref
  const formRef = useRef(null);
  //点击通过按钮
  const onClickPass = (record) => {
    formRef.current.record = record;
    formRef.current.type = 0;
    formRef.current.submit();
  };
  //点击拒绝按钮
  const onClickReject = (record) => {
    formRef.current.record = record;
    formRef.current.type = 1;
    formRef.current.submit();
  };
  //提交表单
  const handleSubmit = async (value) => {
    try {
      //通过图片审核，如果是视频直接跳过
      const base = baseRequest();
      const response = await fetch("/op/moment/review", {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          moment_ids: [parseInt(formRef.current.record.momentId, 10)],
          op_type: formRef.current.type,
          manually_review_opinion: value[formRef.current.record.momentId]
            ? value[formRef.current.record.momentId]
            : "",
          ...base,
        }),
      });
      const _data = await response.json();
      if (_data.ret === -1) {
        alert(_data.msg);
        return;
      }
      //取消数据展示
      setShowData(
        showData.filter(
          (item) => item.momentId !== formRef.current.record.momentId
        )
      );
    } catch (error) {
      console.error(error);
    }
  };
  //获取数据
  const [data, setData] = useState([]);
  const [offset, setOffset] = useState(0);
  const [more, setMore] = useState(1);
  const getData = async () => {
    if (!more) return;
    let querryStatus;
    switch (current) {
      case "operatorReviewing":
        querryStatus = 4;
        break;
      case "machineReviewing":
        querryStatus = 3;
        break;
      case "onlySelfCanSee":
        querryStatus = 6;
        break;
      default:
        break;
    }
    try {
      const base = baseRequest();
      const response = await fetch("/op/moment_audit_task/list", {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          status: querryStatus,
          offset: offset,
          limit: 200,
          ...base,
        }),
      });
      const temData = await response.json();
      console.log(temData);
      if (temData.ret === -1) {
        alert(temData.msg);
        return;
      }
      //匹配表格格式
      const structedData = temData.data.list.map((item, index) => {
        return {
          key: index,
          momentId: item.moment_audit_task.associative_table_id,
          creator: item?.streamer_ext,
          id: {
            media: item.image_audit_task_vo.id,
            text: item.text_audit_task_vo.id,
          },
          newMedia: {
            media: item.moment_audit_task.audited_media,
            text: item.moment_audit_task.audited_text,
          },
          info: item.moment_audit_task.audited_media
            ? {
                mediaType:
                  item.moment_audit_task.audited_media.videos.length === 0
                    ? "image"
                    : "video",
                media:
                  item.moment_audit_task.audited_media.videos.length === 0
                    ? item.image_audit_task_vo.image_audits
                    : item.moment_audit_task.image_audit_opinion,
                text: item.text_audit_task_vo.text_audit,
              }
            : { text: item.text_audit_task_vo.text_audit },
          submitTime: new Date(
            item.moment_audit_task.ct * 1000
          ).toLocaleString(),
          remarks: {
            // media: item.image_audit_task_vo.remarks,
            // text: item.moment_audit_task.remarks,
            manually_review_status:
              item.moment_audit_task?.manually_review_status,
            manually_review_opinion:
              item.moment_audit_task?.manually_review_opinion,
            manually_review_operator:
              item.moment_audit_task?.manually_review_operator,
          },
          others: {
            media: {
              id: item.image_audit_task_vo.id,
              audited_media: item.image_audit_task_vo.audited_media,
              associative_database:
                item.image_audit_task_vo.associative_database,
              associative_table_name:
                item.image_audit_task_vo.associative_table_name,
              associative_table_id:
                item.image_audit_task_vo.associative_table_id,
              associative_table_column:
                item.image_audit_task_vo.associative_table_column,
            },
            text: {
              id: item.text_audit_task_vo.id,
              audited_text: item.text_audit_task_vo.audited_text,
              associative_database:
                item.text_audit_task_vo.associative_database,
              associative_table_name:
                item.text_audit_task_vo.associative_table_name,
              associative_table_id:
                item.text_audit_task_vo.associative_table_id,
              associative_table_column:
                item.text_audit_task_vo.associative_table_column,
            },
          },
        };
      });
      setData([...data, ...structedData]);
      setOffset(temData.data.offset);
      setMore(temData.data.more);
    } catch (error) {
      console.error(error);
    }
  };
  useEffect(() => {
    getData();
  }, [current]);

  //展示的数据
  const [showData, setShowData] = useState([]);
  useEffect(() => {
    setShowData(data);
  }, [data]);
  //表单提交失败
  const onFinishFailed = (errorInfo) => {
    console.log("Failed:", errorInfo);
  };
  return (
    <div style={{ marginLeft: 20, marginRight: 20 }}>
      <p>
        {current === "operatorReviewing" && `运营待审核${showData.length}条`}
        {current === "onlySelfCanSee" && `审核未通过${showData.length}条`}
      </p>
      <Form
        ref={formRef}
        name="remarks"
        onFinish={handleSubmit}
        onFinishFailed={onFinishFailed}
      >
        <Table
          columns={columns}
          dataSource={showData}
          pagination={{ pageSize: 20 }}
          scroll={{ y: window.innerHeight - 300 }}
        />
      </Form>
    </div>
  );
};

export default function PostMachineReview() {
  const navigate = useNavigate();
  //当前tab
  const location = useLocation();
  const pathname = location.pathname.split("/")[2] || "operatorReviewing";
  const [current, setCurrent] = useState(pathname);
  //tab名称
  const items = [
    {
      label: "运营待审核",
      key: "operatorReviewing",
    },
    {
      label: "机审中",
      key: "machineReviewing",
    },
    {
      label: "审核未通过",
      key: "onlySelfCanSee",
    },
  ];
  const onClick = (e) => {
    setCurrent(e.key);
    navigate(e.key);
    window.location.reload();
  };

  return (
    <div>
      <Menu
        onClick={onClick}
        selectedKeys={[current]}
        mode="horizontal"
        items={items}
      />
      <Routes>
        <Route
          path="/"
          element={<Navigate to="/postMachineReview/operatorReviewing" />}
        />
        <Route
          path="/operatorReviewing"
          element={<PostMachineReviewContent current="operatorReviewing" />}
        />
        <Route
          path="/machineReviewing"
          element={<PostMachineReviewContent current="machineReviewing" />}
        />
        <Route
          path="/onlySelfCanSee"
          element={<PostMachineReviewContent current="onlySelfCanSee" />}
        />
      </Routes>
    </div>
  );
}
